@@ -29,12 +29,12 @@
 #'   and \code{progressive = TRUE}, ignored otherwise).
 #'   Defaults to NULL, in which a set of log(n, 2)^2 non-identical
 #'   sequences are chosen from the list of sequences by k-means clustering.
-#' @param seqweights either NULL (default; all sequences are given weights
+#' @param seqweights either NULL (all sequences are given weights
 #'   of 1), a numeric vector the same length as \code{x} representing
 #'   the sequence weights used to derive the model, or a character string giving
 #'   the method to derive the weights from the sequences. Currently only the
 #'   \code{"Gerstein"} method is supported (default). For this method, a
-#'   tree is first created by k-mer counting (see \code{\link[phylogram]{topdown}}),
+#'   tree is first created by k-mer counting (see \code{\link[kmer]{cluster}}),
 #'   and sequence weights are then derived from the tree using the 'bottom up'
 #'   algorithm of Gerstein et al (1994).
 #' @param refine the method used to iteratively refine the model parameters
@@ -279,7 +279,7 @@ align.list <- function(x, model = NULL, progressive = FALSE, seeds = NULL,
     navailcores <- parallel::detectCores()
     if(identical(cores, "autodetect")) cores <- navailcores - 1
     if(cores > 1){
-      if(cores > navailcores) stop("Number of cores is more than number available")
+      # if(cores > navailcores) stop("No. cores is more than number available")
       if(!quiet) cat("Multithreading over", cores, "cores\n")
       cores <- parallel::makeCluster(cores)
       para <- TRUE
